
0.5
===
* Add support to parse descriptions.

0.4
===
* Major improvements to the package caching logic.

0.3
===
* Add package caching


0.2
===
* Add support for Spyne 2.9 APIs.


0.1
===
* First working version
